package internal

import (
	"encoding/json"
	"gitea.cdlsxd.cn/BaseSystem/plugin/proto"
	"plugins/union_pay_redpack/internal/po"
	"plugins/union_pay_redpack/internal/utils"
	"plugins/union_pay_redpack/internal/vo"
)

type Config struct {
	AppId   string `json:"app_id"`
	BaseUri string `json:"base_uri"`

	ChNlId string `json:"chnlId"` // 渠道方代码
	IV     string `json:"iv"`     // 加密密钥
	KEY    string `json:"key"`    // 加密密钥
	Prk    string `json:"prk"`    // 私钥
	Npk    string `json:"npk"`    // 回调公钥
}

func transConfig(config []byte) (*Config, error) {
	var c Config
	err := json.Unmarshal(config, &c)
	if err != nil {
		return nil, err
	}
	return &c, nil
}

func (c *Config) orderReq(in *proto.OrderRequest) (*po.OrderReq, error) {
	type OrderExtra struct {
		OrderDt string `json:"orderDt"`
	}
	var e OrderExtra
	_ = json.Unmarshal(in.Order.Extra, &e)

	mobile, err := utils.Encrypt([]byte(in.Order.Account), []byte(c.KEY), []byte(c.IV))
	if err != nil {
		return nil, err
	}
	return &po.OrderReq{
		ChNlId:         c.ChNlId,
		AccessId:       vo.AccessId,
		TransDtTm:      "",
		InsAcctTp:      "",
		InsAcctId:      "",
		AcctEntityTp:   "",
		Mobile:         mobile,
		PointTp:        "",
		PointId:        "",
		PointAt:        "",
		DelayIn:        "",
		TempIn:         "",
		InOutTransFlag: "",
		TransDigest:    "",
	}, nil
}

func orderResp(request *proto.OrderRequest, resp po.OrderResp) *proto.OrderResponse {
	data, _ := json.Marshal(resp)
	result := &proto.Result{
		OrderNo: request.Order.OrderNo,
		TradeNo: resp.TransSeq,
		Message: resp.Msg,
		Data:    data,
	}
	if !resp.Code.IsSuccess() {
		result.Status = proto.Status_FAIL
		result.Message = resp.GetMsg()
	} else {
		result.Status = proto.Status_ING
	}
	return &proto.OrderResponse{Result: result}
}

func queryReq(in *proto.QueryRequest, chNlId string) *po.QueryReq {
	type OrderExtra struct {
		OrigDate string `json:"origDate"`
	}
	var e OrderExtra
	_ = json.Unmarshal(in.Order.Extra, &e)
	return &po.QueryReq{
		ChNlId:        chNlId,
		TransSeq:      "",
		TransDtTm:     "",
		OrigTransSeq:  "",
		OrigTransDtTm: "",
		AcctEntityTp:  "",
		Mobile:        "",
	}
}

func queryResp(request *proto.QueryRequest, resp po.QueryResp) *proto.QueryResponse {
	data, _ := json.Marshal(resp)
	result := &proto.Result{
		OrderNo: request.Order.OrderNo,
		TradeNo: request.Order.TradeNo,
		Status:  resp.AcquireSt.GetOrderStatus(),
		Message: resp.GetMsg(),
		Data:    data,
	}
	return &proto.QueryResponse{Result: result}
}

func notifyResp() *proto.NotifyResponse {
	result := &proto.Result{
		Status:  proto.Status_ING,
		OrderNo: "",
		TradeNo: "",
		Message: "无回调通知",
		Data:    nil,
		Extra:   nil,
	}
	return &proto.NotifyResponse{Result: result}
}
